@@ -6,7 +6,7 @@
 #'  Returns a table of monitors and related metadata at sites with the
 #'    provided parameter, stateFIPS, county_code, and sitenum for
 #'    bdate - edate time frame.
-#' @note all monitors that operated between the bdate and edate will be returned
+#' @note All monitors that operated between the bdate and edate will be returned
 #' @family Aggregate _by_site functions
 #' @inheritParams aqs_services_by_site
 #' @importFrom magrittr `%<>%`
@@ -22,14 +22,14 @@
 #'           selected stateFIPS, county, and sitenum combination.
 #' @examples
 #'  #Returns a tibble of the SO2 monitors at Hawaii
-#'  #  Volcanoes NP site (\#0007) in Hawaii County, HI that were operating on
-#'  #  May 1 , 2015. (Note, all monitors that operated between the bdate and
-#'  #  edate will be returned)
+#'  #  Volcanoes NP site (\#0007) in Hawaii County, HI that were operating
+#'  # between May 1 , 2015-2019. (Note, all monitors that operated between the
+#'  # bdate and edate will be returned).
 #'  \dontrun{
 #'            aqs_monitors_by_site(parameter = "42401",
 #'                                   bdate = as.Date("20150501",
 #'                                                      format="%Y%m%d"),
-#'                                   edate = as.Date("20150502",
+#'                                   edate = as.Date("20190501",
 #'                                                      format="%Y%m%d"),
 #'                                   stateFIPS = "15",
 #'                                   countycode = "001",
@@ -93,8 +93,8 @@ aqs_monitors_by_site <- function(parameter, bdate, edate, stateFIPS,
 #' @return a tibble or an AQS_Data Mart_APIv2 S3 object containing flow rate
 #'           audit data for the requested sitenum, countycode and stateFIPS. An
 #'           AQS_Data_Mart_APIv2 object is a 2 item named list in which the
-#'           first item (\$Header) is a tibble of header information from the
-#'           AQS API and the second item (\$Data) is a tibble of the data
+#'           first item ($Header) is a tibble of header information from the
+#'           AQS API and the second item ($Data) is a tibble of the data
 #'           returned.
 #' @examples # returns a tibble of flow rate audit data
 #'           #  for the Wylam site (#2003) in Jefferson County, AL
@@ -164,9 +164,9 @@ aqs_qa_flowrateaudit_by_site <- function(parameter, bdate, edate,
 #'                        purposes in addition to the data requested.
 #' @return a tibble or an AQS_Data Mart_APIv2 S3 object containing one point
 #'            qc data for the requested site. A AQS_Data_Mart_APIv2 object is a
-#'            2 item named list in which the first item (\$Header) is a tibble
+#'            2 item named list in which the first item ($Header) is a tibble
 #'            of header information from the AQS API and the second item
-#'            (\$Data) is a tibble of the data returned.
+#'            ($Data) is a tibble of the data returned.
 #' @examples # returns a tibbble of One Point QC data for
 #'           #  ozone at the Truro National Seashore site (\#0002) in
 #'           #  Barnstable County, MA for January 2018:
@@ -213,7 +213,7 @@ aqs_qa_one_point_qc_by_site <- function(parameter, bdate, edate,
 #'                Returns a table of Performance Evaluation Program (PEP) audit
 #'                data aggregated by parameter code, stateFIPS, countycode and
 #'                site number for the time frame between bdate and edate.
-#' @note The AQS API only allows for a single year of one point pep audit data
+#' @note The AQS API only allows for a single year of pep audit data
 #'         to be retrieved at a time. This function conveniently extracts date
 #'         information from the bdate and edate parameters then makes repeated
 #'         calls to the AQSAPI retrieving a maximum of one calendar year of data
@@ -234,21 +234,21 @@ aqs_qa_one_point_qc_by_site <- function(parameter, bdate, edate,
 #'                        purposes in addition to the data requested.
 #' @return a tibble or an AQS_Data Mart_APIv2 S3 object containing quality
 #'           assurance PEP audit data within a site. A AQS_Data_Mart_APIv2
-#'           object is a 2 item named list in which the first item (\$Header) is
+#'           object is a 2 item named list in which the first item ($Header) is
 #'           a tibble of header information from the AQS API and the second item
-#'           (\$Data) is a tibble of the data returned.
-#' @examples # returns a aqs_v2 S3 object of pep Audit data for FRM PM2.5
+#'           ($Data) is a tibble of the data returned.
+#' @examples # returns a tibble of pep Audit data for FRM PM2.5
 #'           #  at the Huntsville Old Airport site (\#0014) in Madison County,
 #'           #  AL for 2017 - 2019.
 #'  \dontrun{aqs_qa_pep_audit_by_site(parameter = "88101",
 #'                                    bdate = as.Date("20170101",
 #'                                                    format = "%Y%m%d"),
 #'                                    edate = as.Date("20191231",
-#'                                                      format = "%Y%m%d"),
+#'                                                    format = "%Y%m%d"),
 #'                                    stateFIPS = "01",
 #'                                    countycode = "089",
 #'                                    sitenum = "0014"
-#'                                        )
+#'                                    )
 #'            }
 #' @export
 aqs_qa_pep_audit_by_site <- function(parameter, bdate, edate,
@@ -320,9 +320,8 @@ aqs_qa_pep_audit_by_site <- function(parameter, bdate, edate,
 #'           is a 2 item named list in which the first item /(/$Header/) is a
 #'           tibble of header information from the AQS API and the second item
 #'           /(/$Data/) is a tibble of the data returned.
-#' @examples #Returns a AQS_Data Mart_APIv2 S3 object of ozone monitoring
-#'           #  data for the Millbrook School site (/#0014) in
-#'           #  Wake County, NC for June 18, 2017.
+#' @examples #Returns a table of ozone monitoring data for the Millbrook School
+#'           # site (/#0014) in Wake County, NC for June 18, 2017.
 #'  \dontrun{
 #'             aqs_sampledata_by_site(parameter = "44201",
 #'                                    bdate = as.Date("20170618",
@@ -396,8 +395,8 @@ aqs_sampledata_by_site <- function(parameter, bdate, edate, stateFIPS,
 #' @return a tibble or an AQS_Data Mart_APIv2 S3 object containing annual
 #'           summary data for the sitenum, countycode and stateFIPS requested.
 #'           A AQS_Data Mart_APIv2 is a 2 item named list in which the first
-#'           item (\$Header) is a tibble of header information from the AQS API
-#'           and the second item (\$Data) is a tibble of the data returned.
+#'           item ($Header) is a tibble of header information from the AQS API
+#'           and the second item ($Data) is a tibble of the data returned.
 #' @examples # Returns a tibble of annual summary ozone
 #'           #  data for the Millbrook School site (\#0014) in Wake County,
 #'           #  NC for 2017 (Note, for annual data, only the
@@ -514,7 +513,7 @@ aqs_qa_blanks_by_site <- function(parameter, bdate, edate, stateFIPS,
 
 #' @title aqs_dailysummary_by_site
 #' @description \lifecycle{stable}
-#'        Returns multiple years of data where daily data is
+#'        Returns multiple years of data where dailysummary data is
 #'        aggregated at the site level. Returned is a daily summary
 #'        matching the input parameter stateFIPS, countycode, and sitenum
 #'        provided for bdate - edate time frame. Data is aggregated at the
@@ -542,8 +541,8 @@ aqs_qa_blanks_by_site <- function(parameter, bdate, edate, stateFIPS,
 #' @return a tibble or an AQS_Data Mart_APIv2 S3 object that contains daily
 #'           summary statistics for the given parameter for a single site. An
 #'           AQS_Data Mart_APIv2 is a 2 item named list in which the first item
-#'           (\$Header) is a tibble of header information from the AQS API and
-#'           the second item (\$Data) is a tibble of the data returned.
+#'           ($Header) is a tibble of header information from the AQS API and
+#'           the second item ($Data) is a tibble of the data returned.
 #' @examples #Returns a tibble of daily summary ozone
 #'           #  data for the Millbrook School site (\#0014) in Wake County,
 #'           #  NC for June 18, 2017.
@@ -589,17 +588,17 @@ aqs_dailysummary_by_site <- function(parameter, bdate, edate, stateFIPS,
 #'                Returns a table of collocated assessment data aggregated by
 #'                 matching input parameter, stateFIPS, county_code, and
 #'                 sitenum provided for bdate - edate time frame.
-#' @note The AQS API only allows for a single year of collocated assessments to
-#'         be retrieved at a time. This function conveniently extracts date
-#'         information from the bdate and edate parameters then makes repeated
-#'         calls to the AQSAPI retrieving a maximum of one calendar year of data
-#'         at a time. Each calendar year of data requires a separate API call so
-#'         multiple years of data will require multiple API calls. As the number
-#'         of years of data being requested increases so does the length of time
-#'         that it will take to retrieve results. There is also a 5 second wait
-#'         time inserted between successive API calls to prevent overloading the
-#'         API server. This operation has a linear run time of
-#'         /(Big O notation: O/(n + 5 seconds/)/).
+#' @note The AQS API only allows for a single year of collocated assessments
+#'         data to be retrieved at a time. This function conveniently extracts
+#'         date information from the bdate and edate parameters then makes
+#'         repeated calls to the AQSAPI retrieving a maximum of one calendar
+#'         year of data at a time. Each calendar year of data requires a
+#'         separate API call so multiple years of data will require multiple API
+#'         calls. As the number of years of data being requested increases so
+#'         does the length of time that it will take to retrieve results. There
+#'         is also a 5 second wait time inserted between successive API calls to
+#'         prevent overloading the API server. This operation has a linear run
+#'         time of /(Big O notation: O/(n + 5 seconds/)/).
 #' @family Aggregate _by_site functions
 #' @inheritParams aqs_services_by_site
 #' @importFrom magrittr `%<>%`
@@ -615,9 +614,9 @@ aqs_dailysummary_by_site <- function(parameter, bdate, edate, stateFIPS,
 #'           and the second item ($Data) is a tibble of the data returned.
 #' @examples #returns a tibble of collocated assessment data
 #'           #  for FRM PM2.5 at the Huntsville Old Airport site (\#0014)
-#'           #  in Madison County, AL for January 2013:
+#'           #  in Madison County, AL for January 2015:
 #'  \dontrun{aqs_qa_collocated_assessments_by_site(parameter = "88101",
-#'                                                 bdate = as.Date("20130101",
+#'                                                 bdate = as.Date("20150101",
 #'                                                             format = "%Y%m%d"
 #'                                                                ),
 #'                                                 edate = as.Date("20150131",
@@ -687,7 +686,7 @@ aqs_qa_collocated_assessments_by_site <- function(parameter, bdate, edate,
 #'           item ($Header) is a tibble of header information from the AQS API
 #'           and the second item ($Data) is a tibble of the data returned.
 #' @examples # returns a tibble of flow rate verification
-#'           #  data for the Muscle Shoals site (#0014) in Colbert County, AL
+#'           #  data for the Muscle Shoals site (#1002) in Colbert County, AL
 #'           #  for January 2018:
 #'  \dontrun{aqs_qa_flowrateverification_by_site(parameter = "88101",
 #'                                               bdate = as.Date("20170101",
@@ -734,7 +733,7 @@ aqs_qa_flowrateverification_by_site <- function(parameter, bdate, edate,
 #'          a parameter code aggregated by matching input parameter, sitenum,
 #'          countycode and stateFIPS provided for bdate - edate time frame.
 #'          Includes data both in submitted and standard units
-#' @note The AQS API only allows for a single year of transactiondata to be
+#' @note The AQS API only allows for a single year of transaction data to be
 #'         retrieved at a time. This function conveniently extracts date
 #'         information from the bdate and edate parameters then makes repeated
 #'         calls to the AQSAPI retrieving a maximum of one calendar year of
@@ -797,7 +796,7 @@ aqs_transactionsample_by_site <- function(parameter, bdate, edate,
 }
 
 
-#' @title aqs_qa_annualpeferomanceeval_by_site
+#' @title aqs_qa_annualperformanceeval_by_site
 #' @description \lifecycle{stable}
 #'        Returns quality assurance performance evaluation data - aggregated by
 #'          site for a parameter code aggregated by matching input
@@ -823,10 +822,9 @@ aqs_transactionsample_by_site <- function(parameter, bdate, edate,
 #'                        from the API server mostly used for debugging
 #'                        purposes in addition to the data requested.
 #' @importFrom magrittr `%<>%`
-#' @examples #Returns an AQS_Data Mart_APIv2 S3 object or a tibble
-#'           #   containing annual performance evaluation data for ozone at the
-#'           #    Fairhope site in Baldwin County, AL for 2017
-#'  \dontrun{  aqs_qa_annualpeferomanceeval_by_site(parameter = "44201",
+#' @examples #Returns a tibble containing annual performance evaluation data for
+#'           # ozone at the Fairhope site in Baldwin County, AL for 2017
+#'  \dontrun{  aqs_qa_annualperformanceeval_by_site(parameter = "44201",
 #'                                                  bdate = as.Date("20170101",
 #'                                                          format = "%Y%m%d"),
 #'                                                  edate = as.Date("20171231",
@@ -844,7 +842,7 @@ aqs_transactionsample_by_site <- function(parameter, bdate, edate,
 #'           information from the AQS API and the second item ($Data) is a
 #'           tibble of the data returned.
 #' @export
-aqs_qa_annualpeferomanceeval_by_site <- function(parameter, bdate, edate,
+aqs_qa_annualperformanceeval_by_site <- function(parameter, bdate, edate,
                                                  stateFIPS, countycode, sitenum,
                                                  cbdate = NA_Date_,
                                                  cedate = NA_Date_,
@@ -878,9 +876,9 @@ aqs_qa_annualpeferomanceeval_by_site <- function(parameter, bdate, edate,
 #'          input parameter, sitenum, countycode and stateFIPS provided for
 #'          bdate - edate time frame.
 #' @note The AQS API only allows for a single year of quality assurance
-#'         Annual Performance Evaluations data to be retrieved at a time. This
-#'         function conveniently extracts date information from the bdate
-#'         and edate parameters then makes repeated calls to the AQSAPI
+#'         Annual Performance Evaluations transaction data to be retrieved at a
+#'         time. This function conveniently extracts date information from the
+#'         bdate and edate parameters then makes repeated calls to the AQSAPI
 #'         retrieving a maximum of one calendar year of data at a time. Each
 #'         calendar year of data requires a separate API call so multiple years
 #'         of data will require multiple API calls. As the number of years of
@@ -897,9 +895,9 @@ aqs_qa_annualpeferomanceeval_by_site <- function(parameter, bdate, edate,
 #'                        from the API server mostly used for debugging
 #'                        purposes in addition to the data requested.
 #' @importFrom magrittr `%<>%`
-#' @examples #Returns an AQS_Data Mart_APIv2 S3 object or a tibble
-#'           #   containing annual performance evaluation data (raw) for ozone
-#'           # at the Fairhope site in Baldwin County, AL for 2017 in RD format.
+#' @examples #Returns a tibble containing annual performance evaluation data
+#'           # (raw) for ozone at the Fairhope site in Baldwin County, AL for
+#'           # 2017 in RD format.
 #' \dontrun{aqs_qa_annualperformanceevaltransaction_by_site(parameter = "44201",
 #'                                                   bdate = as.Date("20170101",
 #'                                                           format = "%Y%m%d"),
@@ -962,6 +960,9 @@ aqs_qa_annualperformanceevaltransaction_by_site <- function(parameter, bdate,
 #'         time inserted between successive API calls to prevent overloading the
 #'         API server. This operation has a linear run time of
 #'         /(Big O notation: O/(n + 5 seconds/)/).
+#'
+#'         Also Note that for quarterly data, only the year portion of the bdate
+#'         and edate are used and all 4 quarters in the year are returned.
 #' @family Aggregate _by_county functions
 #' @inheritParams aqs_services_by_site
 #' @importFrom magrittr `%<>%`
@@ -973,12 +974,12 @@ aqs_qa_annualperformanceevaltransaction_by_site <- function(parameter, bdate,
 #' @return a tibble or an AQS_Data Mart_APIv2 S3 object that contains quarterly
 #'           summary statistics for the given parameter for a single countycode
 #'           and stateFIPS combination. An AQS_Data Mart_APIv2 is a 2 item named
-#'           list in which the first item (\$Header) is a tibble of header
-#'           information from the AQS API and the second item (\$Data) is a
+#'           list in which the first item ($Header) is a tibble of header
+#'           information from the AQS API and the second item ($Data) is a
 #'           tibble of the data returned.
-#' @examples # returns an aqs S3 object containing quarterly summaries for
+#' @examples # returns a tibble containing quarterly summaries for
 #'           #  FRM/FEM PM2.5 data for Millbrook School in Wake County, NC
-#'           #  between January and February 2016
+#'           #  for each quarter of 2016
 #'  \dontrun{aqs_quarterlysummary_by_site(parameter = "88101",
 #'                                        bdate = as.Date("20160101",
 #'                                                        format = "%Y%m%d"),
