@@ -27,8 +27,8 @@
 aqs_credentials <- function(username = NA_character_, key = NA_character_)
 {
   # nocov
-  #The code simply stores the credentials as a R global variable since the
-  #Data Mart server only issues "key" and not "passwords" we don't need to
+  #The code simply stores the credentials as a R option. Since the
+  #Data Mart server only issues a "key" and not a "password" we don't need to
   #worry about securing the credentials with complicated code such as involving
   #salt and hashes and etc.
    if (!is.na(username) ||
@@ -39,7 +39,9 @@ aqs_credentials <- function(username = NA_character_, key = NA_character_)
    {
     options(aqs_username = username)
     options(aqs_key = key)
-  } else {cat("Please enter a valid username and key  \n") }
+    #credentials <- options(list(aqs_username = username, aqs_key = key))
+    #on.exit(options(credentials), add = TRUE)
+  } else {warning("Please enter a valid username and key  \n") }
 } #no cov end
 
 
@@ -63,7 +65,7 @@ aqs_credentials <- function(username = NA_character_, key = NA_character_)
 #' @note The '@' character needs to be escaped with the '/' character.
 #' @importFrom glue glue
 #' @importFrom magrittr `%>%`
-#' @importFrom httr GET
+#' @importFrom httr2 request
 #' @importFrom glue glue
 #' @examples # to register a new user or generate a new key with the email
 #'           #  address "John.Doe/@myemail.com"
@@ -74,9 +76,18 @@ aqs_credentials <- function(username = NA_character_, key = NA_character_)
 #' @export
 aqs_sign_up <- function(email)
 { #nocov start
+  #We do not want aqs_sign_up registering new users as part of
+  #the unit testing procedures.
 
-  url <- glue("https://aqs.epa.gov/data/api/signup?email={email}")
-  httr::GET(url)
+  # user_agent <- glue("User:{email} via RAQSAPI-{packageVersion('RAQSAPI')}
+  #                     library for R")
+
+  url <- glue("https://aqs.epa.gov/data/api/signup?email={email}") %>%
+    request() %>%
+    req_perform()
+  #for some reason user_agent isn't working
+  #%>%
+  #req_user_agent(string = user_agent)
   glue("A verification email will be sent to {email}  \n") %>%
     message()
 } #nocov end
