@@ -1,20 +1,29 @@
+#' @importFrom dplyr pull
 #' @importFrom magrittr `%>%`()
+#' @import testthat
 test_that("list functions", {
-testthat::skip_if_offline()
-testthat::skip_on_cran()
-server <- "AQSDatamartAPI"
-datamartAPI_user <- "test@aqs.api"
+  testthat::skip_on_cran()
+  testthat::skip_if_offline()
 
-datamartAPI_user <- "test@aqs.api"
+  if(file.exists("local.R"))
+  {
+    source("helper.R")
+    AQScredentials <- RAQSAPItestsetup_helper()
+    datamartAPI_user <- AQScredentials$datamartAPI_user
+    datamartAPI_key <- AQScredentials$datamartAPI_key
+  } else {
+    datamartAPI_user <- Sys.getenv("RAQSAPIUSERNAME", names = TRUE)
+    datamartAPI_key <- Sys.getenv("RAQSAPIKEY", names = TRUE)
+  }
+  RAQSAPI::aqs_credentials(username = datamartAPI_user,
+                           key = datamartAPI_key
+  )
 
-  aqs_credentials(username = datamartAPI_user,
-                           key = "test"
-                           )
-
-  aqs_isavailable(return_header = TRUE)$Header$status %>%
-  expect_match(regexp = "API service is up and running healthy",
-               fixed = FALSE
-               )
+  aqs_isavailable() %>%
+    dplyr::pull(status) %>%
+    expect_match(regexp = "API service is up and running healthy",
+                 fixed = FALSE
+                 )
 
   aqs_fields_by_service(service = "list",
                         return_header = TRUE)$Header$status %>%
@@ -34,16 +43,22 @@ datamartAPI_user <- "test@aqs.api"
                         )$Header$status %>%
     expect_match(regexp = "Success")
 
+  aqs_pqaos(return_header = TRUE)$Header$status %>%
+    expect_match(regexp = "Success")
+
+  aqs_cbsas(return_header = TRUE)$Header$status %>%
+    expect_match(regexp = "Success")
+
   aqs_classes(return_header = TRUE)$Header$status %>%
     expect_match(regexp = "Success")
 
-aqs_sites_by_county(stateFIPS = "15",
+  aqs_sites_by_county(stateFIPS = "15",
                     countycode = "001",
                     return_header = TRUE)$Header$status %>%
     expect_match(regexp = "Success")
 
-aqs_parameters_by_class(class = "CRITERIA",
-                        return_header = TRUE)$Header$status %>%
+  aqs_parameters_by_class(class = "CRITERIA",
+                          return_header = TRUE)$Header$status %>%
     expect_match(regexp = "Success")
 
 })
